The goal of piles is provide lightweight, turnkey, extensible composite data 
structures. 

piles's framework supports a wide range of coding styles. You can create 
complex multiple inheritance structures with mixins galore or simpler, 
compositional objects. Even though the data structures are necessarily object-
oriented, all of the tools to modify them are also available as functions, for 
those who prefer a more funcitonal approaching to programming. 

The project is also highly documented so that users and developers and make
piles work with their projects. It is designed for Python coders at all 
levels. Beginners should be able to follow the readable code and internal
documentation to understand how it works. More advanced users should find
complex and tricky problems addressed through efficient code.


